@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from semantha_sdk.api import SemanthaAPIEndpoint
-from semantha_sdk.response import SemanthaPlatformResponse
+from semantha_sdk.model.Diffs import Diffs, Diff as _DiffDTO
 
 
 class Diff(SemanthaAPIEndpoint):
@@ -9,7 +11,7 @@ class Diff(SemanthaAPIEndpoint):
     def _endpoint(self):
         return self._parent_endpoint + "/diff"
 
-    def create_diff(self, left_text: str, right_text: str) -> SemanthaPlatformResponse:
+    def post(self, left_text: str, right_text: str) -> list[_DiffDTO]:
         """ Create a diff between two given texts.
 
         Args:
@@ -18,9 +20,9 @@ class Diff(SemanthaAPIEndpoint):
         """
 
         return self._session.post(
-            self._endpoint,
-            {
+            url=self._endpoint,
+            body={
                 "left": left_text,
                 "right": right_text
             }
-        ).execute()
+        ).execute().to(Diffs).diffs
