@@ -1,5 +1,6 @@
 from semantha_sdk.api import SemanthaAPIEndpoint
 from semantha_sdk.api.Boostwords import Boostwords
+from semantha_sdk.api.Synonyms import Synonyms
 from semantha_sdk.rest.RestClient import RestClient
 
 
@@ -9,6 +10,7 @@ class DomainModel(SemanthaAPIEndpoint):
         super().__init__(session, parent_endpoint)
         self._domain_name = domain_name
         self.__boostwords = Boostwords(session, self._endpoint)
+        self.__synonyms = Synonyms(session, self._endpoint)
 
     @property
     def _endpoint(self):
@@ -18,6 +20,10 @@ class DomainModel(SemanthaAPIEndpoint):
     def boostwords(self):
         return self.__boostwords
 
+    @property
+    def synonyms(self):
+        return self.__synonyms
+
 
 class Domains:
 
