@@ -3,11 +3,10 @@ from typing import Optional
 
 from semantha_sdk.api import SemanthaAPIEndpoint
 from semantha_sdk.model.Document import Document
-from semantha_sdk.model.Entity import Entity
 from semantha_sdk.model.NamedEntities import NamedEntities
 from semantha_sdk.model.Paragraphs import Paragraph
 from semantha_sdk.model.ReferenceDocuments import ReferenceDocuments as _ReferenceDocumentsDTO, \
-    ReferenceDocumentCollection, Statistic
+    ReferenceDocumentCollection, Statistic, DocumentInformation
 from semantha_sdk.model.Sentences import Sentence
 from semantha_sdk.response import SemanthaPlatformResponse
 
@@ -156,31 +155,29 @@ class ReferenceDocuments(SemanthaAPIEndpoint):
         """ Delete a reference document by id """
         self._session.delete(f"{self._endpoint}/{document_id}").execute()
 
-    def post_update(
+    def patch_document_information(
             self,
             document_id: str,
-            id: str,
-            name: str,
-            tags: list[str],
-            metadata: str,
-            file_name: str,
-            created: int,
-            updated: int,
-            processed: bool,
-            lang: str,
-            content: str,
-            documentClass: Entity,
-            derived_tags: list[str],
-            color: str,
-            derived_color: str,
-            comment: str,
-            derived_comment: str,
+            update: Document,
             query_by_name: bool = False
-    ) -> SemanthaPlatformResponse:
-        """ Update reference document by id (not yet implemented)"""
-        # TODO implement and adapt DocString
-        raise NotImplementedError("Reference documents can not be updated yet")
-        return self._session.patch(f"{self._endpoint}/{document_id}").execute()
+    ) -> DocumentInformation:
+        """ Update reference document by id
+
+        Args:
+            document_id (str): the id of the document to update
+            update (DocumentInformation): (partial) document information that should be updated. Please provide an
+                                          instance of DocumentInformation (semantha_sdk.model.ReferenceDocuments.
+                                          DocumentInformation). E.g. to alter (only) the name of the document you can
+                                          use something like Document({"name": "new name"}).
+            query_by_name (bool): whether to query by name or not
+        """
+        return self._session.patch(
+            url=f"{self._endpoint}/{document_id}",
+            json=update.data,
+            q_params={
+                "querybyname": str(query_by_name)
+            }
+        ).execute().to(DocumentInformation)
 
     def get_paragraph(self, document_id: str, paragraph_id: str) -> Paragraph:
         """ Get a paragraph of a reference document by document id and paragraph id"""
@@ -190,10 +187,19 @@ class ReferenceDocuments(SemanthaAPIEndpoint):
         """ Delete a paragraph of a reference document by document id and paragraph id"""
         self._session.delete(f"{self._endpoint}/{document_id}/paragraphs/{paragraph_id}").execute()
 
-    def patch_paragraph(self, document_id: str, paragraph_id: str) -> SemanthaPlatformResponse:
-        """(not yet implemented)"""
-        # TODO implement and adapt DocString
-        return self._session.patch(f"{self._endpoint}/{document_id}/paragraphs/{paragraph_id}").execute()
+    def patch_paragraph(self, document_id: str, paragraph_id: str, update: Paragraph) -> Paragraph:
+        """Update a Paragraph by document id and paragraph id
+        Args:
+            document_id (str): the id of the document to update
+            paragraph_id (str):the id of the paragraph to update
+            update (Paragraph): (partial) paragraph information that should be updated. Please provide an instance of
+                                Paragraph (semantha_sdk.model.Paragraphs.Paragraph). E.g. to alter (only) the text of
+                                the paragraph you can use something like Paragraph({"text": "updated text"}).
+        """
+        return self._session.patch(
+            url=f"{self._endpoint}/{document_id}/paragraphs/{paragraph_id}",
+            json=update.data
+        ).execute().to(Paragraph)
 
     def get_sentence(self, document_id: str, sentence_id: str) -> Sentence:
         """ Get a sentence of a reference document by document id and sentence id"""
