@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from typing import Optional
 
-from semantha_sdk.model import Reference, Page
+from semantha_sdk.model import Reference, Page, SemanthaModelEntity
 from semantha_sdk.model.ReferenceDocuments import DocumentInformation
 
 
@@ -25,3 +27,14 @@ class Document(DocumentInformation):
     @property
     def image_pages(self) -> Optional[str]:
         return None
+
+
+@dataclass(frozen=True)
+class Documents(SemanthaModelEntity):
+
+    def __post_init__(self):
+        assert type(self.data) is list
+
+    @property
+    def documents(self) -> list[Document]:
+        return [Document(raw_document) for raw_document in self.data]
