@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
-from typing import List
 
 from semantha_sdk.model import SemanthaModelEntity
 
@@ -18,5 +19,5 @@ class Domains(SemanthaModelEntity):
         assert type(self.data) is list
 
     @property
-    def domains(self) -> List[Domain]:
+    def domains(self) -> list[Domain]:
         return [Domain(domain["id"], domain["name"], base_url=domain["baseUrl"]) for domain in self.data]
